"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
exports.isString = (x) => typeof x === 'string';
exports.isBuffer = (x) => x != null && x instanceof Buffer;
exports.isStream = (x) => x != null && x instanceof stream_1.Readable;
exports.isURL = (x) => x != null && x instanceof URL;
exports.isFileUri = (x) => exports.isString(x) && x.startsWith('file:');
exports.isPlain = (x) => exports.isString(x) || exports.isStream(x) || exports.isBuffer(x);
exports.isTuple = (x) => Array.isArray(x) &&
    x.length === 2 &&
    typeof x[0] === 'string' &&
    exports.isPlain(x[1]);
exports.isObject = (x) => {
    if (x == null ||
        typeof x !== 'object' ||
        Array.isArray(x) ||
        typeof x[Symbol.iterator] === 'function' ||
        x instanceof URL) {
        return false;
    }
    for (const key in x) {
        if (x.hasOwnProperty(key) && !exports.isPlain(x[key]))
            return false;
    }
    return true;
};
exports.isIterable = (x) => {
    if (x == null || typeof x === 'string')
        return false;
    if (typeof x[Symbol.iterator] === 'function') {
        for (const src of x) {
            if (src == null)
                return false;
            if (!exports.isPlain(src) && !exports.isTuple(src) && !exports.isObject(src))
                return false;
        }
        return true;
    }
    return false;
};
const fileNameRE = /^[\w\s\(\),-]+\.[A-Za-z0-9]+$/;
const MIN_FILE_NAME_LENGTH = 3;
const MAX_FILE_NAME_LENGTH = 50;
exports.isFileName = (x) => exports.isString(x) &&
    !x.startsWith('file:') &&
    x.length >= MIN_FILE_NAME_LENGTH &&
    x.length <= MAX_FILE_NAME_LENGTH &&
    fileNameRE.test(x);
