"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("fs");
const stream_1 = require("stream");
const _source_checkers_1 = require("./_source-checkers");
exports.toTuples = (source, recursive = false) => {
    if (_source_checkers_1.isURL(source))
        return [];
    if (_source_checkers_1.isFileUri(source)) {
        return !recursive && path_1.extname(source) === '.html'
            ? [['index.html', source]]
            : [[path_1.basename(source), source]];
    }
    if (_source_checkers_1.isString(source) || _source_checkers_1.isBuffer(source)) {
        return [['index.html', source]];
    }
    if (_source_checkers_1.isStream(source)) {
        if (source instanceof fs_1.ReadStream) {
            const name = path_1.basename(String(source.path));
            return !recursive && path_1.extname(name) === '.html'
                ? [['index.html', source]]
                : [[name, source]];
        }
        else {
            return [['index.html', source]];
        }
    }
    if (_source_checkers_1.isTuple(source) && _source_checkers_1.isFileName(source[0])) {
        return [source];
    }
    if (_source_checkers_1.isObject(source)) {
        const ret = [];
        for (const key in source) {
            if (source.hasOwnProperty(key)) {
                ret.push([key, source[key]]);
            }
        }
        return ret;
    }
    if (recursive) {
        throw new Error('Bad source, possible recursive iterables?');
    }
    if (_source_checkers_1.isIterable(source)) {
        const ret = [];
        for (const src of source) {
            ret.push(...exports.toTuples(src, true));
        }
        return ret;
    }
    throw new Error(`Bad source, don't know what to do with "${source}"`);
};
exports.fromFile = (path) => fs_1.createReadStream(path.replace(/^file:(\/\/)?/, ''));
exports.toStream = (source) => _source_checkers_1.isStream(source)
    ? source
    : _source_checkers_1.isFileUri(source)
        ? exports.fromFile(source)
        :
            new stream_1.Readable({
                read() {
                    this.push(source);
                    this.push(null);
                },
            });
exports.toStreams = (source) => {
    if (!source)
        return [];
    const tuples = exports.toTuples(source);
    const ret = [];
    for (let i = 0; i < tuples.length; i++) {
        ret.push([tuples[i][0], exports.toStream(tuples[i][1])]);
    }
    return ret;
};
