"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const http = require("http");
const https = require("https");
const parse = (url) => {
    const _url = new URL(url);
    const request = _url.protocol === 'http:' ? http.request : https.request;
    return [_url, request];
};
function post(url, data) {
    const [_url, request] = parse(url);
    return new Promise((resolve, reject) => {
        const req = request(_url, Object.assign({ method: 'POST', headers: data.getHeaders() }, this));
        req.on('error', reject);
        req.on('response', res => {
            if (res.statusCode === 200) {
                resolve(res);
            }
            else {
                res.resume();
                reject(new Error(res.statusCode + ' ' + res.statusMessage));
            }
        });
        data.pipe(req);
    });
}
exports.post = post;
function get(url) {
    const [_url, request] = parse(url);
    return new Promise((resolve, reject) => {
        const req = request(_url, Object.assign({ method: 'GET' }, this));
        req.on('error', reject);
        req.on('response', res => {
            if (res.statusCode === 200) {
                resolve(res);
            }
            else {
                res.resume();
                reject(new Error(res.statusCode + ' ' + res.statusMessage));
            }
        });
        req.end();
    });
}
exports.get = get;
const client = (config) => ({
    post: post.bind(config || null),
    get: get.bind(config || null),
});
exports.default = client;
